# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.0.0

import winrt.system
from winrt._winrt_windows_web_atompub import (
    AtomPubClient,
    ResourceCollection,
    ServiceDocument,
    Workspace,
)

__all__ = [
    "AtomPubClient",
    "ResourceCollection",
    "ServiceDocument",
    "Workspace",
]

